<?php

	class GeradorRelatorio {

		//Recebe uma revista e gera e armazena um arquivo com o resumo da
		//edicao atual da revista.
		public function gerarResumo($revista) {

			$meses = array("Janeiro", "Fevereiro", "Março", "Abril", "Maio", "Junho", "Julho","Agosto", "Setembro", "Outubro", "Novembro", "Dezembro");
	
			$arq = fopen('relat-resumo.txt', 'w');
			$edicao = $revista->getEdicao();
			fwrite($arq, $revista->getNome() . ", num. " . $edicao->getNumero() . ", volume ". $edicao->getVolume());
			fwrite($arq, " - " . $meses[ $edicao->getDataPublicacao()[1] - 1] . " de " . $edicao->getDataPublicacao()[2]."\n");
			
			if ($revista->getEdicao()->getTema() == NULL) {
				fwrite($arq, "Tema: ");
				fwrite($arq, "\n");	
			}
			else	
				fwrite($arq, "Tema: " . $edicao->getTema()->getNome()."\n");

			if ($edicao->getEditorChefe() == NULL) {
				fwrite($arq, "Editor-chefe: ");
				fwrite($arq, "\n");
			}	
			else	
				fwrite($arq, "Editor-chefe: " . $edicao->getEditorChefe()->getNome()."\n");

			fwrite($arq, "\n");	
			fwrite($arq, "Consistência dos dados:\n");
			fwrite($arq, "- Nenhum problema encontrado.\n");
			fwrite($arq, "\n");	

			fwrite($arq, "Artigos submetidos: " . $revista->getNumArtigos() ."\n");
			fwrite($arq, "Revisores capacitados: " . $revista->getNumRevisoresCapacitados() ."\n");
			$num_rev_envolvidos = $revista->getNumRevisoresEnvolvidos(); 
			fwrite($arq, "Revisores envolvidos: " . $num_rev_envolvidos ."\n");
			
			$mediaArtRev = (float)count($revista->getRevisoes())/(float)$num_rev_envolvidos;
			$mediaArtRevString = (string) $mediaArtRev;
			$mediaArtRevString = number_format($mediaArtRevString, 2, ',', '');
			fwrite($arq, "Média artigos/revisor: " . $mediaArtRevString ."\n");
			
			fclose($arq);
		}

		
		
		//Comparador para ordenar um array de artigos pela media das notas.
		function comparadorArtigos($a, $b) {
			$mediaA = $a->getMediaNotas();
			$mediaB = $b->getMediaNotas();
			if ( $mediaA < $mediaB)
				return (1);
			elseif ($mediaA > $mediaB)
				return (-1);
			else
				return 0;
		}
		
		//Comparador para ordenar um array de revisoes pelo nome do revisor.
		function comparadorRevisoes($a, $b) {
			$revisorA = $a->getRevisor()->getNome();
			$revisorB = $b->getRevisor()->getNome();
			if ( $revisorA < $revisorB)
				return (-1);
			elseif ($revisorA > $revisorB)
				return (1);
			else
				return 0;
		}
		
		
		//Recebe uma revista e gera e armazena um arquivo com relatorio de
		//revisoes efetuadas nos artigos da edicao atual da revista.
		public function gerarRelatorioRevisoes ($revista) {
			
			$lista_artigos = array();
			foreach ($revista->getArrayArtigos() as $k => $a) {
					$a->computarMedia();
					$lista_artigos[] = $a;					
			}
			
			$arq = fopen('relat-revisoes.csv', 'w');
			fwrite($arq, "Artigo;Autor de contato;Média das avaliações;Revisor 1; Revisor 2; Revisor 3\n");	
			
			usort($lista_artigos, array($this,"comparadorArtigos")); //Ordenando artigos por media de nota
			
			foreach ($lista_artigos as $artigo) {
				fwrite($arq, $artigo->getTitulo() . ";") ;
				fwrite($arq, $artigo->getContato()->getNome() .";");
				
				$media_notas = (string) round($artigo->getMediaNotas(), 2);
				$media_notas = 	number_format($media_notas, 2, ',', '');
				fwrite($arq, $media_notas .";");
			
				$array_revisoes = $artigo->getRevisoes();	
				usort($array_revisoes, array($this,"comparadorRevisoes")); //Ordenando revisoes por nome do revisor
				fwrite($arq, $array_revisoes[0]->getRevisor()->getNome() .";");
				fwrite($arq, $array_revisoes[1]->getRevisor()->getNome() .";");
				fwrite($arq, $array_revisoes[2]->getRevisor()->getNome() ."\n");
			}
	
			fclose($arq);
		}


		//Comparador para ordenar um array de revisores pelo nome do revisor.
		function comparadorRevisores($a, $b) {
			$revisorA = $a->getNome();
			$revisorB = $b->getNome();
			//echo "-> ". $revisorA . " < ". $revisorB . "\n";
			if ( $revisorA < $revisorB)
				return (-1);
			elseif ($revisorA > $revisorB)
				return (1);
			else
				return 0;
		}
		
		//Recebe uma revista e gera e armazena um arquivo com um relatorio 
		//dos revisores que trabalharam na revisao dos artigos da edicao atual da revista.
		public function gerarRelatorioRevisores($revista) {
			$arq = fopen('relat-revisores.csv', 'w');		
			fwrite($arq, "Revisor;Qtd. artigos revisados;Média das notas atribuídas\n");

			$array_revisores = $revista->getRevisores();
			usort($array_revisores, array($this,"comparadorRevisores")); //Ordenando revisores por seus nomes
			
			foreach ($array_revisores as $revisor) {
				$num_artigos_revisados = 0;
				$soma_medias_notas_atribuidas = 0;

				$conj_revisoes = $revista->getRevisoes();
				foreach ($conj_revisoes as $revisao) {
					if ($revisor == $revisao->getRevisor()) {
						$num_artigos_revisados++;
						$soma_medias_notas_atribuidas = $revisao->getMediaNotas() + $soma_medias_notas_atribuidas;
					}
				}
				if ($num_artigos_revisados != 0) {
					fwrite($arq, $revisor->getNome() .";");
					fwrite($arq, $num_artigos_revisados .";");
					
					$media_notas = (string) round($soma_medias_notas_atribuidas/$num_artigos_revisados, 2);
					fwrite($arq, number_format($media_notas, 2, ',', '')."\n");
				}
			}
			fclose($arq);
		}
	}

?>
