<?php
	require_once("Pessoa.php");
	require_once("Tema.php");
	
	class Leitor {
		
		//Recebe uma string representando um arquivo contendo dados de pessoas
		//e uma revista. Le o arquivo e armazena suas informacoes
		//na revista.
		function lerArquivoPessoas($arquivo, $revista) {
			$arq = fopen($arquivo, "r");		
			if ($arq == NULL) {
				echo "Arquivo \"" . $arquivo . "\" nao encontrado.\n";
				exit(0);
			}
			
			fgets($arq); //Pula primeira linha com descricao dos campos
			
			while(($dados = fgetcsv($arq, 0, ";")) !== FALSE) {
				
				list($codigo, $nome, $email, $senha, $instituicao, $endereco, $tipo) = $dados;

				if ($tipo == "A") {
					$autor = new Autor ($codigo, $nome, $email, $senha, $instituicao, $endereco);
					$revista->addAutor($codigo, $autor);								
				}
				else if($tipo == "R") {
					$revisor = new Revisor ($codigo, $nome, $email, $senha, $instituicao, $endereco);
					$revista->addRevisor($codigo, $revisor);
				}
			}

			fclose($arq);
		}

		//Recebe uma string representando um arquivo contendo dados de temas
		//e uma revista. Le o arquivo e armazena suas informacoes na revista.
		public function lerArquivoTemas($arquivo, $revista) {
			$arq = fopen($arquivo, "r");		
			if ($arq == NULL) {
				echo "Arquivo \"" . $arquivo . "\" nao encontrado.\n";
				exit(0);
			}
			
			fgets($arq); //Pula primeira linha com descricao dos campos
			
			while(($dados = fgetcsv($arq, 0, ";")) !== FALSE) {
				
				list($codigo, $nome, $revisores_capacitados) = $dados;	 
				$cod_revisores = explode(",", $revisores_capacitados);

				$tema = new Tema($codigo, $nome);
				
				foreach($cod_revisores as $cod) {
					$codigo_revisor = (int) $cod;
					$revisor = $revista->getRevisor($codigo_revisor);
					
					if ($revisor != NULL)
						$tema->addRevisor($revisor);				
				}			
				$revista->addTema($codigo, $tema);
			}
		fclose($arq);
		}

		//Recebe uma string representando um arquivo contendo dados da edicao
		//e uma revista. Le o arquivo e armazena suas informacoes na revista.
		public function lerArquivoEdicao($arquivo, $revista) {
			$arq = fopen($arquivo, "r");		
			if ($arq == NULL) {
				echo "Arquivo \"" . $arquivo . "\" nao encontrado.\n";
				exit(0);
			}
						
			$nome_tema = fgets($arq);
			$nome_tema = rtrim($nome_tema, "\n\r");
			$tema = $revista->getTema($nome_tema);
	
			$nome_editor_chefe = fgets($arq);
			$nome_editor_chefe = rtrim($nome_editor_chefe, "\n\r");
			$editor_chefe = $revista->getRevisorPorNome($nome_editor_chefe);
			
			$volume = (int)fgets($arq);
			$numero = (int)fgets($arq);
			$data_publicacao = rtrim(fgets($arq), "\n\r"); 

			$edicao = new Edicao($tema,$editor_chefe, $volume, $numero, $data_publicacao);
			$revista->setEdicao($edicao);
		
			fclose($arq);
		}

		//Recebe uma string representando um arquivo contendo dados de artigos
		//e uma revista. Le o arquivo e armazena suas informacoes na revista.
		public function lerArquivoArtigos($arquivo, $revista) {
			$arq = fopen($arquivo, "r");		
			if ($arq == NULL) {
				echo "Arquivo \"" . $arquivo . "\" nao encontrado.\n";
				exit(0);
			}
			
			fgets($arq); //Pula a primeira linha
			
			while(($dados = fgetcsv($arq, 0, ";")) !== FALSE) {
				$codigo = (int)$dados[0];
				$titulo = $dados[1];
				$autores = $dados[2];
				
				$artigo = new Artigo($codigo, $titulo);
				$array_cod_autores = explode(",", $autores);
				$num_autores = count($array_cod_autores);
				
				for ($i = 0; $i < $num_autores; $i++) {
					$array_autores[$i] = $revista->getAutor((int)$array_cod_autores[$i]);
				}
					
				
				$artigo->setAutores($array_autores);
								
				if ($num_autores > 1) {
					$autor_contato = $revista->getAutor((int)$dados[3]);
					$artigo->setContato($autor_contato);
				}
				else {
					$artigo->setContato($array_autores[0]);
				}
				
				$revista->addArtigo($codigo,$artigo);
			}
		
			fclose($arq);
		}


		//Recebe uma string representando um arquivo contendo dados de revisoes
		//e uma revista. Le o arquivo e armazena suas informacoes na revista.
		public function lerArquivoRevisoes($arquivo, $revista) {
			$arq = fopen($arquivo, "r");		
			if ($arq == NULL) {
				echo "Arquivo \"" . $arquivo . "\" nao encontrado.\n";
				exit(0);
			}
		
			fgets($arq);  //Pula a primeira linha
	
			while(($dados = fgetcsv($arq, 0, ";")) !== FALSE) {

				$cod_artigo = (int)$dados[0];
				$artigo = $revista->getArtigo($cod_artigo);
	
				$cod_revisor = (int)$dados[1];
				$revisor = $revista->getRevisor($cod_revisor);

				$nOrig = floatval( str_replace(",", ".", $dados[2]) );
				$nCont = floatval( str_replace(",", ".", $dados[3]) );
				$nApres = floatval( str_replace(",", ".", $dados[4]) );
				
				$revisao = new Revisao($artigo, $revisor, $nOrig, $nCont, $nApres);
				$revista->addRevisao($revisao);
				$artigo->addRevisao($revisao);
			}
			
			fclose($arq);
		}
	
	}
?>
